# netcrypt

**Secure socket communication and tunneling for Python**

---

##  Overview
`netcrypt` is a Python library designed to simplify encrypted communication over networks. It supports AES and RSA encryption, secure tunnel setup, and socket communication for secure file transfers or messaging.

---

## Features
- AES & Fernet encryption for data-in-transit
- RSA key generation and usage for asymmetric encryption
- Encrypted TCP client-server sockets
- Command-line interface for tunnels and key management
- Optional tunnel threading support for background services

---

##  Installation
```bash
pip install netcrypt
```

---

## Usage
### Generate AES Key:
```bash
netcrypt keygen --generate --keyfile aes.key
```

### Start Secure Tunnel:
#### Server
```bash
netcrypt tunnel --mode server --keyfile aes.key --host 0.0.0.0 --port 9000
```
#### Client
```bash
netcrypt tunnel --mode client --keyfile aes.key --host 127.0.0.1 --port 9000
```

### Generate RSA Key Pair:
```bash
netcrypt rsagen --out-private rsa_private.pem --out-public rsa_public.pem
```

---

##  Project Structure
```
netcrypt/
├── encryptors.py
├── key_manager.py
├── sockets.py
├── tunnel.py
├── cli.py
└── __init__.py
```

---

## Run Tests
```bash
pytest tests/
```

---

## License

MIT License

Copyright (c) 2025 Raghava Chellu

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.





